@@ -469,23 +469,23 @@ class opensshStatus(StatusMenuItem):
         for line in sshNetstat:
             if self.wlanIP in line:
                 countAllWLAN += 1
-        countOutWLAN = 0
+        countInWLAN = 0
         for line in sshNetstat:
-            line = " ".join(line.split())
-            if self.wlanIP + ":ssh ESTABLISHED" in line:
-                countOutWLAN += 1
-        countInWLAN = countAllWLAN - countOutWLAN
+            element = " ".join(line.split()).split()[3]
+            if self.wlanIP + ":ssh" in element:
+                countInWLAN += 1
+        countOutWLAN = countAllWLAN - countInWLAN
         
         countAllUSB = 0
         for line in sshNetstat:
             if self.usbIP in line:
                 countAllUSB += 1
-        countOutUSB = 0
+        countInUSB = 0
         for line in sshNetstat:
-            line = " ".join(line.split())
-            if self.usbIP + ":ssh ESTABLISHED" in line:
-                countOutUSB += 1
-        countInUSB = countAllUSB - countOutUSB
+            element = " ".join(line.split()).split()[3]
+            if self.usbIP + ":ssh" in element:
+                countInUSB += 1
+        countOutUSB = countAllUSB - countInUSB
         
         self.sshConnected = countInWLAN + countInUSB
         
@@ -1012,12 +1012,12 @@ class opensshStatus(StatusMenuItem):
         for line in sshNetstat:
             if self.wlanIP in line:
                 countAllWLAN += 1
-        countOutWLAN = 0
+        countInWLAN = 0
         for line in sshNetstat:
-            line = " ".join(line.split())
-            if self.wlanIP + ":ssh ESTABLISHED" in line:
-                countOutWLAN += 1
-        countInWLAN = countAllWLAN - countOutWLAN
+            element = " ".join(line.split()).split()[3]
+            if self.wlanIP + ":ssh" in element:
+                countInWLAN += 1
+        countOutWLAN = countAllWLAN - countInWLAN
         self.labelCountInWLAN = countInWLAN
         self.labelCountOutWLAN = countOutWLAN
         
@@ -1025,12 +1025,12 @@ class opensshStatus(StatusMenuItem):
         for line in sshNetstat:
             if self.usbIP in line:
                 countAllUSB += 1
-        countOutUSB = 0
+        countInUSB = 0
         for line in sshNetstat:
-            line = " ".join(line.split())
-            if self.usbIP + ":ssh ESTABLISHED" in line:
-                countOutUSB += 1
-        countInUSB = countAllUSB - countOutUSB
+            element = " ".join(line.split()).split()[3]
+            if self.usbIP + ":ssh" in element:
+                countInUSB += 1
+        countOutUSB = countAllUSB - countInUSB
         self.labelCountInUSB = countInUSB
         self.labelCountOutUSB = countOutUSB
         
